@@ -275,11 +275,6 @@ def sync_transactions(
         spreadsheet_id: str,
         num_days: int = 30) -> None:
     """Put transaction data into Google Sheet.
-    TODO: raise errors in the following cases:
-    - Google credentials are invalid
-    - Plaid credentials are invalid
-    - Spreadsheet ID is invalid
-    - Access tokens are invalid
     """
     transactions = get_transactions_from_gsheet(gsheets_service, spreadsheet_id)
     for token in access_tokens:
