@@ -40,10 +40,11 @@ if os.environ.get('GOOGLE_CLOUD_PROJECT'):
 else:
     session_manager = FlaskSessionManager(session)
     print('Using Flask session manager')
+enable_restrictions = bool(os.environ.get('GSHEETS_PLAID_RESTRICTIONS_ENABLED'))
 
 @app.before_request
 def load_session():
-    if request.endpoint in ('login', 'sign_in_with_google_callback'):
+    if request.endpoint in ('login', 'sign_in_with_google_callback', 'sign_out'):
         return
     if not session_manager.user_id:
         user_id = request.cookies.get('user_id')
@@ -282,12 +283,18 @@ def remove_plaid_item():
     return redirect(redirect_url)
 
 @app.route('/forget-spreadsheet')
-def forget_spreadsheet() -> None:
+def forget_spreadsheet():
     del session_manager['spreadsheet_id']
     del session_manager['spreadsheet_url']
     redirect_url = request.args.get('redirect_url', url_for('index'))
     return redirect(redirect_url)
 
+@app.route('/delete-my-data')
+def delete_my_data():
+    request.cookies
+    session_manager.delete_session()
+    return redirect(url_for('sign_out'))
+
 def status_check(session_data: dict) -> dict:
     plaid_env = session_data.get('plaid_env', 'sandbox')
     plaid_items = get_plaid_items(session_data)
@@ -315,6 +322,8 @@ def parse_google_cloud_client_config() -> dict:
     return client_config
 
 def user_allowed_sync(session_data: dict) -> bool:
+    if not enable_restrictions:
+        return True
     last_sync = session_data.get('last_sync')
     if not last_sync:
         return True
@@ -344,7 +353,10 @@ def validate_plaid_credentials(plaid_env: str, client_id: str, secret: str) -> b
 def validate_plaid_access_tokens(plaid_items: dict, session_data: dict) -> bool:
     if len(plaid_items) == 0:
         return None
-    plaid_client = build_plaid_client(session_data)
+    try:
+        plaid_client = build_plaid_client(session_data)
+    except ValueError:
+        return False
     for access_token in plaid_items.values():
         try:
             plaid_client.item_get(ItemGetRequest(access_token))
